
# Slot: union_of


indicates that the domain class consists exactly of the members of the classes in the range

URI: [linkml:union_of](https://w3id.org/linkml/union_of)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..\*</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
